@@ -1,5 +1,4 @@
 """ Supports preview. """
-
 from django.shortcuts import render
 
 from . import settings
@@ -11,6 +10,12 @@ def preview(request):
     :returns: A rendered preview
 
     """
+    if settings.MARKDOWN_PROTECT_PREVIEW:
+        user = getattr(request, 'user', None)
+        if user and not user.is_staff:
+            from django.contrib.auth.views import redirect_to_login
+            return redirect_to_login(request.get_full_path())
+
     return render(
         request, settings.MARKDOWN_PREVIEW_TEMPLATE, dict(
             content=request.REQUEST.get('data', 'No content posted'),
